﻿


using EFLol;
using Microsoft.Data.Sqlite;
using Microsoft.EntityFrameworkCore;

namespace TestUnitaire
{
	public class TestEfLol
	{


		//InMemoryTest
		[Fact]
		public void AddInMemory()
		{
			//connection must be opened to use In-memory database
			var connection = new SqliteConnection("DataSource=:memory:");
			connection.Open();

			var options = new DbContextOptionsBuilder<ChampionContext>()
				.UseSqlite(connection)
				.Options;

			//prepares the database with one instance of the context
			using (var context = new ChampionContext(options))
			{
				//context.Database.OpenConnection();
				context.Database.EnsureCreated();

				ChampionEntity chewie = new ChampionEntity { Name = "Chewbacca", Bio = "Zeus is the king of the gods." };
				ChampionEntity yoda = new ChampionEntity { Name = "Yoda", Bio = "Zeus is the king of the gods." };
				ChampionEntity ewok = new ChampionEntity { Name = "Ewok", Bio = "Zeus is the king of the gods." };

				context.Champions.Add(chewie);
				context.Champions.Add(yoda);
				context.Champions.Add(ewok);
				context.SaveChanges();
			}

			//uses another instance of the context to do the tests
			using (var context = new ChampionContext(options))
			{
				context.Database.EnsureCreated();

				Assert.Equal(3, context.Champions.Count());
				Assert.Equal("Chewbacca", context.Champions.First().Name);
			}
		}

		[Fact]
		public void ModifyTestInMemory()
		{
			var options = new DbContextOptionsBuilder<ChampionContext>()
				.UseInMemoryDatabase(databaseName: "Modify_Test_database")
				.Options;

			//prepares the database with one instance of the context
			
			using (var context = new ChampionContext(options))
			{
				ChampionEntity chewie = new ChampionEntity { Name = "Chewbacca", Bio = "Zeus is the king of the gods." };
				ChampionEntity yoda = new ChampionEntity { Name = "Yoda", Bio = "Zeus is the king of the gods." };
				ChampionEntity ewok = new ChampionEntity { Name = "Ewok", Bio = "Zeus is the king of the gods." };

				context.Champions.Add(chewie);
				context.Champions.Add(yoda);
				context.Champions.Add(ewok);
				context.SaveChanges();
			}

			//prepares the database with one instance of the context
			using (var context = new ChampionContext(options))
			{
				string nameToFind = "ew";
				Assert.Equal(2, context.Champions.Where(n => n.Name.ToLower().Contains(nameToFind)).Count());
				nameToFind = "ewo";
				Assert.Equal(1, context.Champions.Where(n => n.Name.ToLower().Contains(nameToFind)).Count());
				var ewok = context.Champions.Where(n => n.Name.ToLower().Contains(nameToFind)).First();
				ewok.Name = "Wicket";
				context.SaveChanges();
			}

			//prepares the database with one instance of the context
			using (var context = new ChampionContext(options))
			{
				string nameToFind = "ew";
				Assert.Equal(1, context.Champions.Where(n => n.Name.ToLower().Contains(nameToFind)).Count());
				nameToFind = "wick";
				Assert.Equal(1, context.Champions.Where(n => n.Name.ToLower().Contains(nameToFind)).Count());
			}
		}
	}
}




